package router

import (
	"github.com/gin-gonic/gin"
	"website-nav/http/api/admin"
	"website-nav/http/middleware"
)

func adminAPI(r *gin.RouterGroup) {
	adminApi := r.Group("admin")
	{
		loginAPI(adminApi)
		userAPI(adminApi)
		navTypeAPI(adminApi)
		navigation(adminApi)
	}
}

// loginAPI
// @description: 登陆相关API
// @param r
func loginAPI(r *gin.RouterGroup) {
	login := r.Group("/login")
	{
		login.GET("/captcha", admin.LoginAPI().Captcha) // 获取验证码
		login.POST("/token", admin.LoginAPI().Login)    // 登陆
	}
}

// userAPI
// @description: 用户相关API
// @param r
func userAPI(r *gin.RouterGroup) {
	user := r.Group("/user")
	user.Use(middleware.Authorization())
	{
		user.GET("/info", admin.UserAPI().GetLoginUser)                // 获取当前登陆用户信息
		user.GET("/list", admin.UserAPI().List)                        // 用户列表
		user.POST("/save", admin.UserAPI().Save)                       // 新增/编辑用户
		user.DELETE("/:id", admin.UserAPI().Delete)                    // 删除用户
		user.PUT("/change-password", admin.UserAPI().ChangePassword)   // 修改密码【当前用户更改自己的】
		user.PUT("/reset-password/:id", admin.UserAPI().ResetPassword) // 重置密码 【重置其他管理员的】
		user.GET("/generate-avatar", admin.UserAPI().GenerateAvatar)   // 生成头像
	}
}

// navTypeAPI
// @description: 导航分类API
// @param r
func navTypeAPI(r *gin.RouterGroup) {
	navType := r.Group("/nav-type")
	navType.Use(middleware.Authorization())
	{
		navType.GET("/list", admin.NavigationTypeAPI().List)     // 分类列表
		navType.POST("/save", admin.NavigationTypeAPI().Save)    // 新增/编辑分类
		navType.DELETE("/:id", admin.NavigationTypeAPI().Delete) // 删除分类
	}
}

// navigation
// @description: 导航相关API
// @param r
func navigation(r *gin.RouterGroup) {
	nav := r.Group("/navigation")
	nav.Use(middleware.Authorization())
	{
		nav.GET("/list", admin.NavigationAPI().List)     // 导航列表
		nav.POST("/save", admin.NavigationAPI().Save)    // 新增/编辑导航
		nav.DELETE("/:id", admin.NavigationAPI().Delete) // 删除导航
	}
}
